@@ -46,6 +46,9 @@ struct _MSFactory{
 	bool_t statistics_enabled;
 	bool_t voip_initd;
 	MSDevicesInfo *devices_info;
+	char *image_resources_dir;
+	char *echo_canceller_filtername;
+	int expected_video_bandwidth;
 };
 
 typedef struct _MSFactory MSFactory;
@@ -61,7 +64,7 @@ extern "C" {
 #define MS2_DEPRECATED __attribute__ ((deprecated))
 #endif
 #endif
-	
+
 /**
  * Create a mediastreamer2 factory. This is the root object that will create everything else from mediastreamer2.
 **/
@@ -72,6 +75,13 @@ MS2_PUBLIC MSFactory *ms_factory_new(void);
 **/
 MS2_PUBLIC MSFactory* ms_factory_new_with_voip(void);
 
+/**
+ * Create a mediastreamer2 factory, initialize all voip related filters, cards and webcam managers and load the plugins from the specified directory.
+ * @param[in] plugins_dir The path where to find the mediastreamer2 plugins to be loaded
+ * @param[in] images_dir The path where to find the images
+ */
+MS2_PUBLIC MSFactory *ms_factory_new_with_voip_and_directories(const char *plugins_dir, const char *images_dir);
+
 /**
  * Create the fallback factory (for compatibility with applications not using MSFactory to create ms2 object)
 **/
@@ -312,6 +322,20 @@ MS2_PUBLIC void ms_factory_set_mtu(MSFactory *obj, int mtu);
 
 MS2_PUBLIC int ms_factory_get_mtu(MSFactory *obj);
 
+/**
+ * Set the name of the echo canceller filter to use.
+ * @param[in] obj MSFactory object
+ * @param[in] filtername The name of the echo canceller filter to use
+ */
+MS2_PUBLIC void ms_factory_set_echo_canceller_filter_name(MSFactory *obj, const char *filtername);
+
+/**
+ * Get the name of the echo canceller filter being used.
+ * @param[in] obj MSFactory object
+ * @return The name of the echo canceller filter being used
+ */
+MS2_PUBLIC const char * ms_factory_get_echo_canceller_filter_name(const MSFactory *obj);
+
 MS2_PUBLIC const struct _MSFmtDescriptor * ms_factory_get_audio_format(MSFactory *obj, const char *mime, int rate, int channels, const char *fmtp);
 
 MS2_PUBLIC const struct _MSFmtDescriptor * ms_factory_get_video_format(MSFactory *obj, const char *mime, MSVideoSize size, float fps, const char *fmtp);
@@ -375,6 +399,24 @@ MS2_PUBLIC MSOfferAnswerContext * ms_factory_create_offer_answer_context(MSFacto
 
 MS2_PUBLIC MSDevicesInfo* ms_factory_get_devices_info(MSFactory *f);
 
+/**
+ * Get the path where the image resources (mainly the nowebcam image) are located.
+ * @param[in] f MSFactory object
+ * @return The path where the image resources are located
+ */
+MS2_PUBLIC const char * ms_factory_get_image_resources_dir(const MSFactory *f);
+
+/**
+ * Set the path where the image resources are located
+ * @param[in] f MSFactory object
+ * @param[in] path The path where the image resources are located
+ */
+MS2_PUBLIC void ms_factory_set_image_resources_dir(MSFactory *f, const char *path);
+
+MS2_PUBLIC void ms_factory_set_expected_bandwidth(MSFactory *f, int bitrate);
+
+MS2_PUBLIC int ms_factory_get_expected_bandwidth(MSFactory *f);
+
 #ifdef __cplusplus
 }
 #endif
